@@ -2,6 +2,7 @@ import pandas as pd
 import numpy as np 
 import time
 import matplotlib.pyplot as plt
+import matplotlib.colors as mcolors
 
 
 
@@ -80,21 +81,29 @@ def PlotComparative(Calculated, Targeted):
 
 
 #Plot the differences of two variables in a sequential series
-def PlotComparative2(Calculated, Targeted):
+def PlotComparative2(Calculated, Targeted, window_size=10):
 
     numdata,numevar = Calculated.shape
     eixoX = np.arange(0, numdata, dtype=int)
-
+            
     for j in range(0,numevar):    
         eixoY1= Targeted[:,j]
         eixoY2= Calculated[:,j]
+        
         eixoY3 = eixoY2 - eixoY1
-    
+
+
+        # preparação para a média móvel
+        rolling_mean = pd.Series(eixoY3).rolling(window_size).mean()
+
         plt.figure(figsize=(12, 5))
         plt.title('Comparison chart calculated variable vs targeted')
         plt.xlabel('Sequence of events')
-        plt.ylabel('Target and predicted variable ' + str(j+1))
-        plt.plot(eixoX, eixoY3, marker = '', color = 'darkblue', label='Targeted')  
+        plt.ylabel('Error, Calculated - Targeted ' + str(j+1))
+        plt.plot(eixoX, eixoY3, marker = '', color = 'darkblue', label='Targeted')
+        # plota a med movel
+        plt.plot(eixoX, rolling_mean, marker='', color = mcolors.to_hex((1, 0, 0)), label='Rolling mean', linestyle='dashed') 
+
         plt.legend(loc = "upper left")
         plt.show()
 
@@ -141,6 +150,50 @@ def PlotComparative3(Calculated, Targeted):
 
 
 
+
+
+#Plot 2 sigma lines
+def PlotComparative4(Calculated, Targeted):
+
+    numdata,numevar = Calculated.shape
+    eixoX = np.arange(0, numdata, dtype=int)
+
+    for j in range(0,numevar):    
+        eixoY1= Targeted[:,j]
+        eixoY2= Calculated[:,j]
+
+        # Cálculo do erro médio e desvio padrão
+        erro_medio = np.mean(eixoY2 - eixoY1)
+        sigma = np.std(eixoY2 - eixoY1)
+    
+        plt.figure(figsize=(12, 5))
+        plt.title('Comparison chart calculated variable vs targeted')
+        plt.xlabel('Sequence of events')
+        plt.ylabel('Target and predicted variable ' + str(j+1))
+        plt.plot(eixoX, eixoY1, marker = '',  label='Targeted')
+
+        plt.plot(eixoX, eixoY1 + erro_medio - 2*sigma, marker = '', c='black', alpha=0.5, linestyle='dashed', label='Expected minimum, -2S')
+        plt.plot(eixoX, eixoY1 + erro_medio + 2*sigma, marker = '', c='black', alpha=0.5, linestyle='dashed', label='Expected maximum, +2S')
+        plt.fill_between(np.arange(len(eixoY1)), eixoY1 + erro_medio - 2*sigma, eixoY1 + erro_medio + 2*sigma, color='gray', alpha=0.1)
+                
+        #plt.plot(eixoX, eixoY2, linestyle='none', c='black', marker = '.', label='Calculated', alpha=0.33)
+        plt.legend(loc = "upper right")
+
+        # Preenchendo a área entre as curvas
+        #plt.fill_between(np.arange(len(eixoY1)), eixoY1 + erro_medio - sigma, eixoY1 + erro_medio + sigma, color='gray', alpha=0.3)
+        #plt.fill_between(np.arange(len(eixoY1)), eixoY1 + erro_medio - 2*sigma, eixoY1 + erro_medio + 2*sigma, color='gray', alpha=0.2)
+        #plt.fill_between(np.arange(len(eixoY1)), eixoY1 + erro_medio - 3*sigma, eixoY1 + erro_medio + 3*sigma, color='gray', alpha=0.1)
+
+        # Adicionando o valor do desvio padrão ao canto superior esquerdo do gráfico
+        plt.text(0.025, 0.95, "sigma = {:.2f}".format(sigma) + ", average = {:.2f}".format(erro_medio), transform=plt.gca().transAxes, fontsize=12, verticalalignment='top')
+        
+        plt.show()
+
+
+        
+
+
+
 #Plot correlation between calculated variables and objectives
 def PlotCorrelation(Calculated, Targeted):
 
@@ -222,8 +275,10 @@ def PlotDispe(Calculated, Targeted):
         valormin = np.min(eixoY1)
         volormed =(valormin+valormax)/2
         eixoY1norma = (eixoY1 - volormed)/(valormax - volormed)                        
+
+        plt.figure(figsize=(15, 5))
         
-        plt.scatter(eixoY1norma,erro,color='blue',s=15,edgecolor='red')
+        plt.scatter(eixoY1norma,erro,color='blue', s=15, edgecolor='red')
         
         plt.plot([-1,1], [0,0], color='black', alpha=0.9, linestyle='dashed')                
 
@@ -232,7 +287,7 @@ def PlotDispe(Calculated, Targeted):
         plt.fill_between((-1,1), erro_medio - 2*sigma, erro_medio + 2*sigma, color='gray', alpha=0.2)
         plt.fill_between((-1,1), erro_medio - 3*sigma, erro_medio + 3*sigma, color='gray', alpha=0.1)
         
-        plt.title('Dispersion plot, 3 sigma colors, variable '+ str(j+1))
+        plt.title('Dispersion plot, 3 sigma gray gradients, variable '+ str(j+1))
         plt.xlabel('Variable normalized: -1,1')
         plt.ylabel('Variable error (calculated-targeted)')
         
@@ -265,7 +320,7 @@ def PlotDispe2(Calculated, Targeted):
         
                         
         plt.title('Target vs sniper, variable '+ str(j+1))
-        plt.scatter(eixoY4,razao,color='blue',s=15,edgecolor='red') #grafico de correlação entre as variaveis procuradas e alvo---
+        plt.scatter(eixoY4,razao,color='red', s=15 , marker = '.', alpha=0.1) #grafico de correlação entre as variaveis procuradas e alvo---
         plt.xlabel('Standard deviation sigma')
         plt.ylabel('Proportion = calculated/targeted')
 
